{ pkgs, ... }:
{
  programs.nixvim = {
    extraPackages = with pkgs; [ fd ];
    enable = true;
    viAlias = true;
    vimAlias = true;
    clipboard.register = [
      "unnamed"
      "unnamedplus"
    ];
    performance = {
      byteCompileLua = {
        enable = true;
        configs = true;
        initLua = false;
        nvimRuntime = true;
        plugins = true;
      };
    };
    # extraFiles = {
    #   "queries/nix/injections.scm".text = lib.mkForce ''
    #     (string_literal
    #       (string_fragment) @lua
    #       (#match? @lua ".*")
    #     )
    #   '';
    # };
    colorscheme = "catppuccin";
    colorschemes.catppuccin = {
      enable = true;
      #lazyLoad.enable = true;
      settings = {
        styles = {
          conditionals = null;
        };
      };
    };
    plugins = {
      aerial.enable = true;
      direnv.enable = true;
      web-devicons.enable = true;
      glow.enable = true;
      gitblame.enable = true;
      git-conflict.enable = true;
      nix.enable = true;
      nix-develop.enable = true;
      image.enable = true;
      which-key.enable = true;
      neocord.enable = false;
      rainbow-delimiters.enable = true;
      neoconf.enable = true;
      colorizer = {
        enable = true;
        settings.user_default_options = {
          names = false;
        };
      };
      comment.enable = true;
      dotnet.enable = true;
      sqlite-lua.enable = true;
      lazydev.enable = true;
    };
    userCommands = {
      ViewInit = {
        desc = "Open the Neovim init.lua file";
        command = "lua vim.cmd('view '.. InitPath)";
      };
    };
    extraConfigLua = # lua
      ''
        InitPath = debug.getinfo(1, "S").source:sub(2)
        print("Neovim init file location: " .. InitPath)
      '';
    extraConfigVim = ''
      set number " enable number lines
    '';
  };
}
